import {
  select,
  csv,
  scaleLinear,
  max,
  scaleBand,
  axisLeft,
  axisBottom,
  format,
  tickSize
} from 'd3'

const svg = select('svg');

const width   = +svg.attr('width');
const height  = +svg.attr('height');



// Aqui foi criada uma função para estabelecer um data join do d3;
// No svg se selecionarmos todos os itens que não existem e atribuirmos
// dados que existem a ele é como se estivéssemos forçando a entrada
// dessas formas. Para tanto utiliza-se o .enter()
const render = data =>{
  	const xValue 			= d => d.Qtd_vendida
  	const yValue 			= d => d.Grupo
    const margin 			= {top: 50, right: 40, bottom: 70, left: 190};
  	const innerWidth	= width - margin.left - margin.right;
    const innerHeight	= height - margin.bottom - margin.top;
  
  	const xScale = scaleLinear()
    	.domain([0, max(data, xValue)])
    	.range([0, innerWidth]);
  	
  	const yScale = scaleBand()
    	.domain(data.map(yValue))
    	.range([0, innerHeight])
    	.padding(0.1);
  	
  	const g = svg.append('g')
  		.attr('transform', `translate(${margin.left}, ${margin.top})`);	
  	
  	const xAxis = axisBottom(xScale)
    	.tickSize(-innerHeight)
  	
  	g.append('g').call(axisLeft(yScale))
  		.selectAll('.domain, .tick line').remove();
  		
  	const xAxisG = g.append('g').call(xAxis)
  		.attr('transform', `translate(0, ${innerHeight})`);
  		
  	xAxisG.select('.domain').remove();	
	
  
  	xAxisG.append('text')
  		.attr('class', 'axis-label')
  		.attr('y', 60)
  		.attr('x', innerWidth/2)
  		.attr('fill', 'black')
      .text('Quantidade de venda');
    
  	g.selectAll('rect').data(data)
  		.enter().append('rect')
  			.attr('class', 'bar')
  			.attr('y', d => yScale(yValue(d)))
  			.attr('width', d => xScale(xValue(d)))
  			.attr('height', yScale.bandwidth())
  		// Para acrescentar um mouseover com informações, append
  		// um título e crie um função de (d)
      .append('title')
  			.text(d => d.Qtd_vendida);
  	
  	g.append('text')
  		.attr('y', -10)
  		.attr('x', innerHeight/2 -190)
  		.text('Grupo do produto x Quantidade de venda');
};

//Representação de uma tabela em JavaScript: usamos a biblioteca csv
// do módulo d3.js, que carrega o dado no diretório e devolve uma
// 'promessa'. Para designar um comando para esse promessa usamos o 
// .then. O forEach é uma forma de iterar em cada linha do documento
// No caso usamos para transformar um string em um int (sinal de +
// faz essa transformação)
csv('data.csv').then(data => {
	data.forEach(d =>{
  	d.Qtd_vendida = +d.Qtd_vendida
  });
 